package
Version:
v0.0.0-...-045640b
Opens a new window with list of versions in this module.
Published: Jul 2, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
KV defines a metadata entry.
type Option func(spec *Spec)
Option defines an optional component of the spec.
Description specifies a short, brief description about the service.
LinkGroup appends a group of links to the provided service.
LogoURL configures the icon for the service.
Metadata allows additional metadata to be attached to a service.
URL configures the services public facing URL that's presented to end users.
Spec defines the elements needed to render a service.
New constructs a spec given a label and set of options.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.